%--------------------------------------------------------------------------
%--------------------------------------------------------------------------
%This is the software to make the images for article

%Requirements:
%   -change path into the path to your folder
%   -make sure the data are in the data folder
%   -make sure there is an image folder to save the images to
%--------------------------------------------------------------------------
%--------------------------------------------------------------------------

clc;
clear;
close all;

path = 'N:\tnw\NS\kuiperslab\Irina\writing_articles\article_flowers\open_data\';

datapath = strcat(path,'data\');
figurepath=strcat(path,'images\');

%%
%This software does the following:
%   -import information of fitted Raman spectra and helicity at different temperatures
%   -determine the helicity of specific flowers at different temperatures
%   -plot Figure 3
%   -plot Figure S6 and S7 of the supplementary materials

%%
%Import all the fitted spectra and the results of the fit

stepX300K = 11.0; stepY300K = 7.0; %calibration piezo V --> um
stepX4K = 3.5; stepY4K = 2.3;  %calibration piezo V --> um

info_helicity_4K = load(strcat(datapath,'Info_0909_flowers_polarization.mat'));
place(1) = 2;
time(1) = str2num(extractBefore(info_helicity_4K.exposuretime{2},'s'))*info_helicity_4K.accumulations{2};
Peak_maxima_4K = info_helicity_4K.Maxima_Lorentz_595{2}/time(1);
Helicity_4K = info_helicity_4K.Helicity;

info_helicity_100K = load(strcat(datapath,'Info_1809_flowers_helicity.mat'));
place(2) = 1;
time(2) = str2num(extractBefore(info_helicity_100K.exposuretime{1},'s'))*info_helicity_100K.accumulations{1};
Peak_maxima_100K = info_helicity_100K.Maxima_Lorentz_595{1}/time(2);
Helicity_100K = info_helicity_100K.Helicity;

info_helicity_200K = load(strcat(datapath,'Info_2309_flowers_helicity.mat'));
place(3) = 1;
time(3) = str2num(extractBefore(info_helicity_200K.exposuretime{1},'s'))*info_helicity_200K.accumulations{1};
Peak_maxima_200K = info_helicity_200K.Maxima_Lorentz_595{1}/time(3);
Helicity_200K = info_helicity_200K.Helicity;

info_helicity_300K = load(strcat(datapath,'Info_2810_flowers_helicity.mat'));
place(4) = 1;
time(4) = str2num(extractBefore(info_helicity_300K.exposuretime{1},'s'))*info_helicity_300K.accumulations{1};
Peak_maxima_300K = info_helicity_300K.Maxima_Lorentz_595{1}/time(4);
Helicity_300K = info_helicity_300K.Helicity;

%%
%Plot Figure 3b: the helicity-resolved Raman spectra at a certain position 
%upon sigma+ %excitation

color_plot{1} = [0 0.6 0]; color_plot{2} = [1 0 1];

ptX(1) = 10; ptY(1) = 18;
ptX(2) = 24; ptY(2) = 12;

fg1 = figure(1); clf(fg1); set(gcf,'Color','w');
plot(info_helicity_4K.Raman{2},(info_helicity_4K.Spectrum{2}(:,1,ptY(2),ptX(2))-info_helicity_4K.background{2}(:,3))/time(1),'r');
hold on
plot(info_helicity_4K.Raman{2},(info_helicity_4K.Spectrum{2}(:,2,ptY(2),ptX(2))-info_helicity_4K.background{2}(:,3))/time(1),'b');
hold off

xlabel('\Delta \nu (cm^{-1})')
ylabel('Intensity (counts/s)')
legend('\sigma_-','\sigma_+')
text(0.05,0.85,'$\star$','units','normalized','color',color_plot{2},'fontsize',50,'interpreter','latex')

xlim([200 1200])

print(fg1,strcat(figurepath,'Figure3b.png'),'-dpng');

%%
%Plot Figure 3c: the helicity-resolved Raman spectra at another position 
%upon sigma+ %excitation

fg2 = figure(2); clf(fg2); set(gcf,'Color','w');
plot(info_helicity_4K.Raman{2},(info_helicity_4K.Spectrum{2}(:,1,ptY(1),ptX(1))-info_helicity_4K.background{2}(:,3))/time(1),'r');
hold on
plot(info_helicity_4K.Raman{2},(info_helicity_4K.Spectrum{2}(:,2,ptY(1),ptX(1))-info_helicity_4K.background{2}(:,3))/time(1),'b');
hold off

xlabel('\Delta \nu (cm^{-1})')
ylabel('Intensity (counts/s)')
legend('\sigma_-','\sigma_+')
text(0.05,0.85,'$\star$','units','normalized','color',color_plot{1},'fontsize',50,'interpreter','latex')

xlim([200 1200])

print(fg2,strcat(figurepath,'Figure3c.png'),'-dpng');


%%
%Plot Figure 3d: the Raman intensity map of a region of flowers

axisX = linspace(stepX4K*info_helicity_4K.sample_x{2}(1)/10,stepX4K*info_helicity_4K.sample_x{2}(end)/10,length(info_helicity_4K.sample_x{2}));
axisY = linspace(stepY4K*info_helicity_4K.sample_y{2}(1)/10,stepY4K*info_helicity_4K.sample_y{2}(end)/10,length(info_helicity_4K.sample_y{2}));

fg3 = figure(3); clf(fg3); set(gcf,'Color','w');

imagesc(axisX,axisY,squeeze(Peak_maxima_4K(1,1,:,:)))
hold on
for ii = 1:2
    plot(axisX(ptX(ii)),axisY(ptY(ii)),'p','color',color_plot{ii},'MarkerFaceColor',color_plot{ii})
    hold on
end

colormap parula
colorbar;
set(gca,'Xdir','reverse')
set(gca,'Ydir','normal')
xlabel('x (\mum)')
ylabel('y (\mum)')

print(fg3,strcat(figurepath,'Figure3d.png'),'-dpng');

%%
%Plot Figure 3e: the Raman helicity map of a region of flowers

fg4 = figure(4); clf(fg4); set(gcf,'Color','w');
imagesc(axisX,axisY,squeeze(Helicity_4K(1,:,:)))
hold on
for ii = 1:2
    plot(axisX(ptX(ii)),axisY(ptY(ii)),'p','color',color_plot{ii},'MarkerFaceColor',color_plot{ii})
    hold on
end

colormap hot
colorbar;
set(gca,'Xdir','reverse')
set(gca,'Ydir','normal')
xlabel('x (\mum)')
ylabel('y (\mum)')

print(fg4,strcat(figurepath,'Figure3e.png'),'-dpng');

%%
%-------------------------------------------------------------------
%Determine the position and helicity of a few specific pixels of the flower marked in green in Fig.1a,c at 4K

number = 1;
green_specif = {};
Green_flower_spec = [];
 
green_specif{1,1} = 18; green_specif{1,2} = 10;
green_specif{2,1} = 16; green_specif{2,2} = 11;
green_specif{3,1} = 14; green_specif{3,2} = 9;

for ii = 1:length(green_specif)
    Green_flower_spec(number,ii) = Helicity_4K(1,green_specif{ii,1},green_specif{ii,2});
    Green_flower_spec_Amode(number,ii) = Helicity_4K(2,green_specif{ii,1},green_specif{ii,2});
end

%%
%Determine the position and helicity of all pixels of the flower marked in green in Fig.1a,c at 4K
number = 1;
green = {};
Green_flower{number} =[];

for ii = 1:3
    green{ii,1} = ii+15;
    green{ii,2} = 13
end

for ii = 4:8
    green{ii,1} = ii+11;
    green{ii,2} = 12
end

for ii = 9:14
    green{ii,1} = ii+5;
    green{ii,2} = 11
end

for ii = 15:19
    green{ii,1} = ii-1;
    green{ii,2} = 10
end

for ii = 20:22
    green{ii,1} = ii-6;
    green{ii,2} = 9
end

for ii = 1:length(green)
    for jj = 1:8
        Green_flower{number}(jj,ii) = Helicity_4K(jj,green{ii,1},green{ii,2});
    end
end


%%
%Determine the position and helicity of a few specific pixels of the flower marked in green in Fig.1a,c at 4K
number = 2;
green_specif = {};
 
green_specif{1,1} = 9; green_specif{1,2} = 5;
green_specif{2,1} = 6; green_specif{2,2} = 4;
green_specif{3,1} = 7; green_specif{3,2} = 6;

for ii = 1:length(green_specif)
    Green_flower_spec(number,ii) = Helicity_100K(1,green_specif{ii,1},green_specif{ii,2});
    Green_flower_spec_Amode(number,ii) = Helicity_100K(2,green_specif{ii,1},green_specif{ii,2});
end

%%
%Determine the position and helicity of all pixels of the flower marked in green in Fig.1a,c at 100K
number = 2;
green = {};
Green_flower{number} =[];

for ii = 1:3
    green{ii,1} = ii+6;
    green{ii,2} = 6
end

for ii = 4:7
    green{ii,1} = ii+2;
    green{ii,2} = 5
end

for ii = 8:10
    green{ii,1} = ii-2;
    green{ii,2} = 4
end

green{11,1} = 6;
green{11,2} = 3

for ii = 1:length(green)
    for jj = 1:8
        Green_flower{number}(jj,ii) = Helicity_100K(jj,green{ii,1},green{ii,2});
    end
end

%%
%Determine the position and helicity of a few specific pixels of the flower marked in green in Fig.1a,c at 4K
number = 3;
green_specif = {};
 
green_specif{1,1} = 12; green_specif{1,2} = 8;
green_specif{2,1} = 9; green_specif{2,2} = 7;
green_specif{3,1} = 10; green_specif{3,2} = 8;

for ii = 1:length(green_specif)
    Green_flower_spec(number,ii) = Helicity_200K(1,green_specif{ii,1},green_specif{ii,2});
    Green_flower_spec_Amode(number,ii) = Helicity_200K(2,green_specif{ii,1},green_specif{ii,2});
end

%%
%Determine the position and helicity of all pixels of the flower marked in green in Fig.1a,c at 200K
number = 3;
green = {};
Green_flower{number} =[];

green{1,1} = 9; green{1,2} = 7

for ii = 2:4
    green{ii,1} = ii+8;
    green{ii,2} = 8
end

for ii = 1:length(green)
    for jj = 1:8
        Green_flower{number}(jj,ii) = Helicity_200K(jj,green{ii,1},green{ii,2});
    end
end

%%
%Determine the position and helicity of a few specific pixels of the flower marked in green in Fig.1a,c at 4K
number = 4;
green_specif = {};
 
green_specif{1,1} = 28; green_specif{1,2} = 17;
green_specif{2,1} = 26; green_specif{2,2} = 17;
green_specif{3,1} = 23; green_specif{3,2} = 17;

for ii = 1:length(green_specif)
    Green_flower_spec(number,ii) = Helicity_300K(1,green_specif{ii,1},green_specif{ii,2});
    Green_flower_spec_Amode(number,ii) = Helicity_300K(2,green_specif{ii,1},green_specif{ii,2});
end

%%
%Determine the position and helicity of all pixels of the flower marked in green in Fig.1a,c at 300K
number = 4;
green = {};
Green_flower{number} =[];

for ii = 1:6
    green{ii,1} = ii+22;
    green{ii,2} = 17
end

for ii = 7:11
    green{ii,1} = ii+16;
    green{ii,2} = 16
end

for ii = 1:length(green)
    for jj = 1:8
        Green_flower{number}(jj,ii) = Helicity_300K(jj,green{ii,1},green{ii,2});
    end
end

%%
%---------------------------------------------------------------------
%Plot Figure 3f: the temperature-dependent Raman helicity of the E2g mode
temperature = [4 100 200 300];

fg5 = figure(5); clf(fg5); set(gcf,'Color','w');

for ii = 1:4
    plot(temperature(ii),Green_flower{ii}(1,:),'pg','MarkerFaceColor','g')
    hold on
end
plot(temperature,Green_flower_spec(1:4,:),'-g')

xlabel('Temperature (K)')
ylabel('Helicity')
title('Temperature dependence helicity E2g mode')

print(fg5,strcat(figurepath,'Figure3f.png'),'-dpng');

%%
%---------------------------------------------------------------------
%Now we plot some information about the A1g mode
%Plot Figure S6a: the intensity of the A1g Raman mode at 4K
%--------------------------------------------------------------------
ptX(1) = 10; ptY(1) = 18;
ptX(2) = 11; ptY(2) = 16;
ptX(3) = 9; ptY(3) = 14;

ptX(4) = 12; ptY(4) = 10;
ptX(5) = 15; ptY(5) = 12;
ptX(6) = 10; ptY(6) = 10;

fg6 = figure(6); clf(fg6); set(gcf,'Color','w');

imagesc(axisX,axisY,squeeze(Peak_maxima_4K(2,1,:,:)))
hold on
for ii = 1:3
    plot(axisX(ptX(ii)),axisY(ptY(ii)),'pg','MarkerFaceColor','g')
    hold on
end
for ii = 4:6
    plot(axisX(ptX(ii)),axisY(ptY(ii)),'p','color',[0.5 0.5 0.5],'MarkerFaceColor',[0.5 0.5 0.5])
    hold on
end

colormap parula
colorbar;
set(gca,'Xdir','reverse')
set(gca,'Ydir','normal')
xlabel('x (\mum)')
ylabel('y (\mum)')
title('Intensity of A_{1g} Raman mode at 4K')

print(fg6,strcat(figurepath,'FigureS6a.png'),'-dpng');

%%
%Plot Figure S6b: the helicity of the A1g Raman mode at 4K
fg7 = figure(7); clf(fg7); set(gcf,'Color','w');
imagesc(axisX,axisY,squeeze(Helicity_4K(2,:,:)))
hold on
for ii = 1:3
    plot(axisX(ptX(ii)),axisY(ptY(ii)),'pg','MarkerFaceColor','g')
    hold on
end
for ii = 4:6
    plot(axisX(ptX(ii)),axisY(ptY(ii)),'p','color',[0.5 0.5 0.5],'MarkerFaceColor',[0.5 0.5 0.5])
    hold on
end

colormap hot
colorbar;
set(gca,'Xdir','reverse')
set(gca,'Ydir','normal')
xlabel('x (\mum)')
ylabel('y (\mum)')
title('Helicity of A_{1g} Raman mode at 4K')

print(fg7,strcat(figurepath,'FigureS6b.png'),'-dpng');

%%
%Plot Figure S6c: the intensity vs. the helicity of the E2g Raman mode

fg8 = figure(8); clf(fg8); set(gcf,'Color','w');

[a,b,c] = size(Helicity_4K)
[d,e,f,g] = size(Peak_maxima_4K)

heli = reshape(Helicity_4K(1,:,:),[1,b*c]);
maxi = reshape(Peak_maxima_4K(1,1,:,:),[1,f*g]);

plot(maxi,heli,'.r')
ylim([-0.2 0.2])

xlabel('Intensity (counts/s)')
ylabel('Helicity')

print(fg8,strcat(figurepath,'FigureS6c.png'),'-dpng');

%%
%Plot Figure S6d: the temperature-dependent Raman helicity of the A1g mode
temperature = [4 100 200 300];

fg9 = figure(9); clf(fg9); set(gcf,'Color','w');

for ii = 1:4
    plot(temperature(ii),Green_flower{ii}(2,:),'pg','MarkerFaceColor','g')
    hold on
end
plot(temperature,Green_flower_spec_Amode(1:4,:),'-g')

xlabel('Temperature (K)')
ylabel('Helicity')
title('Temperature dependence helicity A1g mode')

print(fg9,strcat(figurepath,'FigureS6d.png'),'-dpng');

%%
%-------------------------------------------------------
%Determine the position and helicity of a few specific pixels of the flower
%marked in grey in Fig.S6a,b; at 4K
number = 1;
black_specif = {};
Black_flower_spec = [];
 
black_specif{1,1} = 10; black_specif{1,2} = 12;
black_specif{2,1} = 12; black_specif{2,2} = 16;
black_specif{3,1} = 10; black_specif{3,2} = 10;

for ii = 1:length(black_specif)
    Black_flower_spec(number,ii) = Helicity_4K(1,black_specif{ii,1},black_specif{ii,2});
end


%%
%Determine the position and helicity of all pixels of the flower
%marked in grey in Fig.S6a,b; at 4K
number = 1;
black = {};
Black_flower{number} =[];

for ii = 1:5
    black{ii,1} = ii+8;
    black{ii,2} = 15
end

for ii = 6:10
    black{ii,1} = ii+3;
    black{ii,2} = 14
end

for ii = 11:14
    black{ii,1} = ii-2;
    black{ii,2} = 13
end

for ii = 15:18
    black{ii,1} = ii-7;
    black{ii,2} = 12
end

for ii = 19:22
    black{ii,1} = ii-12;
    black{ii,2} = 11
end

for ii = 23:25
    black{ii,1} = ii-15;
    black{ii,2} = 10
end

for ii = 1:length(black)
    for jj = 1:8
        Black_flower{number}(jj,ii) = Helicity_4K(jj,black{ii,1},black{ii,2});
    end
end

%%
%Determine the position and helicity of a few specific pixels of the flower
%marked in grey in Fig.S6a,b; at 100K
number = 2;
black_specif = {};
 
black_specif{1,1} = 1; black_specif{1,2} = 6;
black_specif{2,1} = 2; black_specif{2,2} = 8;
black_specif{3,1} = 2; black_specif{3,2} = 6;

for ii = 1:length(black_specif)
    Black_flower_spec(number,ii) = Helicity_100K(1,black_specif{ii,1},black_specif{ii,2});
end

%%
%Determine the position and helicity of all pixels of the flower
%marked in grey in Fig.S6a,b; at 100K
number = 2;
black = {};
Black_flower{number} =[];

black{1,1} = 4; black{1,2} = 9;

for ii = 2:4
    black{ii,1} = ii;
    black{ii,2} = 8
end

for ii = 5:8
    black{ii,1} = ii-4;
    black{ii,2} = 7
end

for ii = 9:11
    black{ii,1} = ii-8;
    black{ii,2} = 6
end

for ii = 12:13
    black{ii,1} = ii-11;
    black{ii,2} = 5
end
black{14,1} = 1; black{14,2} = 4

for ii = 1:length(black)
    for jj = 1:8
        Black_flower{number}(jj,ii) = Helicity_100K(jj,black{ii,1},black{ii,2});
    end
end

%%
%Determine the position and helicity of a few specific pixels of the flower
%marked in grey in Fig.S6a,b; at 200K
number = 3;
black_specif = {};
 
black_specif{1,1} = 5; black_specif{1,2} = 8;
black_specif{2,1} = 5; black_specif{2,2} = 9;
black_specif{3,1} = 6; black_specif{3,2} = 8;

for ii = 1:length(black_specif)
    Black_flower_spec(number,ii) = Helicity_200K(1,black_specif{ii,1},black_specif{ii,2});
end

%%
%Determine the position and helicity of all pixels of the flower
%marked in grey in Fig.S6a,b; at 200K
number = 3;
black = {};
Black_flower{number} =[];

black{1,1} = 7; black{1,2} = 10;

for ii = 2:5
    black{ii,1} = ii+3;
    black{ii,2} = 9
end

for ii = 6:8
    black{ii,1} = ii-2;
    black{ii,2} = 8
end

for ii = 1:length(black)
    for jj = 1:8
        Black_flower{number}(jj,ii) = Helicity_200K(jj,black{ii,1},black{ii,2});
    end
end

%%
%Determine the position and helicity of a few specific pixels of the flower
%marked in grey in Fig.S6a,b; at 300K
number = 4;
black_specif = {};
 
black_specif{1,1} = 15; black_specif{1,2} = 18;
black_specif{2,1} = 16; black_specif{2,2} = 19;
black_specif{3,1} = 15; black_specif{3,2} = 17;

for ii = 1:length(black_specif)
    Black_flower_spec(number,ii) = Helicity_300K(1,black_specif{ii,1},black_specif{ii,2});
end

%%
%Determine the position and helicity of all pixels of the flower
%marked in grey in Fig.S6a,b; at 300K
number = 4;
black = {};
Black_flower{number} =[];

for ii = 1:5
    black{ii,1} = ii+15;
    black{ii,2} = 19
end

for ii = 6:8
    black{ii,1} = ii+9;
    black{ii,2} = 18
end

for ii = 9:11
    black{ii,1} = ii+6;
    black{ii,2} = 17
end

for ii = 1:length(black)
    for jj = 1:8
        Black_flower{number}(jj,ii) = Helicity_300K(jj,black{ii,1},black{ii,2});
    end
end

%%
%Plot Figure S6e: the temperature dependence of the helicity of the E2g
%Raman mode of the flower marked in grey
fg10 = figure(10); clf(fg10); set(gcf,'Color','w');

for ii = 1:4
    plot(temperature(ii),Black_flower{ii}(1,:),'p','color',[0.5 0.5 0.5],'MarkerFaceColor',[0.5 0.5 0.5])
    hold on
end
plot(temperature,Black_flower_spec(1:4,:),'-','color',[0.5 0.5 0.5])

xlabel('Temperature (K)')
ylabel('Helicity')
title('Temperature dependence helicity E2g mode')

print(fg10,strcat(figurepath,'FigureS6e.png'),'-dpng');

%%
%Now we go to room temperature, Figure S7
%Plot Figure S7a: the helicity-resolved Raman spectra at a certain position 
%upton sigma+ %excitation

color_plot{1} = [0 0.6 0]; color_plot{2} = [1 0 1];

ptX(1) = 17; ptY(1) = 28;
ptX(2) = 27; ptY(2) = 19;

fg11 = figure(11); clf(fg11); set(gcf,'Color','w');
plot(info_helicity_300K.Raman,(info_helicity_300K.Spectrum(:,1,ptY(2),ptX(2))-info_helicity_300K.background(:,3))/time(4),'r');
hold on
plot(info_helicity_300K.Raman,(info_helicity_300K.Spectrum(:,2,ptY(2),ptX(2))-info_helicity_300K.background(:,3))/time(4),'b');
hold off

xlabel('\Delta \nu (cm^{-1})')
ylabel('Intensity (counts/s)')
legend('\sigma_-','\sigma_+')
text(0.05,0.85,'$\star$','units','normalized','color',color_plot{2},'fontsize',50,'interpreter','latex')

xlim([200 1200])

print(fg11,strcat(figurepath,'FigureS7a.png'),'-dpng');

%%
%Plot Figure S7b: the helicity-resolved Raman spectra at another position 
%upton sigma+ %excitation

fg12 = figure(12); clf(fg12); set(gcf,'Color','w');
plot(info_helicity_300K.Raman,(info_helicity_300K.Spectrum(:,1,ptY(1),ptX(1))-info_helicity_300K.background(:,3))/time(4),'r');
hold on
plot(info_helicity_300K.Raman,(info_helicity_300K.Spectrum(:,2,ptY(1),ptX(1))-info_helicity_300K.background(:,3))/time(4),'b');
hold off

xlabel('\Delta \nu (cm^{-1})')
ylabel('Intensity (counts/s)')
legend('\sigma_-','\sigma_+')
text(0.05,0.85,'$\star$','units','normalized','color',color_plot{1},'fontsize',50,'interpreter','latex')

xlim([200 1200])

print(fg12,strcat(figurepath,'FigureS7b.png'),'-dpng');

%%
%Plot Figure S7c: the intensity vs. the helicity of the E2g Raman mode at
%300K

fg13 = figure(13); clf(fg13); set(gcf,'Color','w');

[a,b,c] = size(Helicity_300K)
[d,e,f,g] = size(Peak_maxima_300K)

heli = reshape(Helicity_300K(1,:,:),[1,b*c]);
maxi = reshape(Peak_maxima_300K(1,1,:,:),[1,f*g]);

plot(maxi,heli,'.r')
ylim([-0.15 0.15])

xlabel('Intensity (counts/s)')
ylabel('Helicity')

print(fg13,strcat(figurepath,'FigureS7c.png'),'-dpng');

%%
%Plot Figure S7d: the Raman intensity map of a region of flowers

axisX = linspace(stepX300K*info_helicity_300K.sample_x{1}(1)/10,stepX300K*info_helicity_300K.sample_x{1}(end)/10,length(info_helicity_300K.sample_x{1}));
axisY = linspace(stepY300K*info_helicity_300K.sample_y{1}(1)/10,stepY300K*info_helicity_300K.sample_y{1}(end)/10,length(info_helicity_300K.sample_y{1}));

fg14 = figure(14); clf(fg14); set(gcf,'Color','w');

imagesc(axisX,axisY,squeeze(Peak_maxima_300K(1,1,:,:)))
hold on
for ii = 1:2
    plot(axisX(ptX(ii)),axisY(ptY(ii)),'p','color',color_plot{ii},'MarkerFaceColor',color_plot{ii})
    hold on
end

colormap parula
colorbar;
set(gca,'Xdir','reverse')
set(gca,'Ydir','normal')
xlabel('x (\mum)')
ylabel('y (\mum)')

print(fg14,strcat(figurepath,'FigureS7d.png'),'-dpng');

%%
%Plot Figure S7e: the Raman helicity map of a region of flowers

fg15 = figure(15); clf(fg15); set(gcf,'Color','w');
imagesc(axisX,axisY,squeeze(Helicity_300K(1,:,:)))
hold on
for ii = 1:2
    plot(axisX(ptX(ii)),axisY(ptY(ii)),'p','color',color_plot{ii},'MarkerFaceColor',color_plot{ii})
    hold on
end

colormap hot
colorbar;
set(gca,'Xdir','reverse')
set(gca,'Ydir','normal')
xlabel('x (\mum)')
ylabel('y (\mum)')

print(fg15,strcat(figurepath,'FigureS7e.png'),'-dpng');










