%--------------------------------------------------------------------------
%--------------------------------------------------------------------------
%This is the software to make the images for article

%Requirements:
%   -change path into the path to your folder
%   -make sure the data are in the data folder
%   -make sure there is an image folder to save the images to
%--------------------------------------------------------------------------
%--------------------------------------------------------------------------

clc;
clear;
close all;

path = 'N:\tnw\NS\kuiperslab\Irina\writing_articles\article_flowers\open_data\';

datapath = strcat(path,'data\');
figurepath=strcat(path,'images\');

%%
%This software does the following:
%   -import information of fitted Raman spectra at different polarization
%   excitation
%   -compensate for the few-pixel shift of the laser due to the rotation of
%   the waveplate
%   -plot the subfigures of Figure 2
%   -plot the subfigures of Figure S4 and S5 of the supplementary materials

%%
%Import the dataset and extract the needed information

stepX4K = 3.5; stepY4K = 2.3;  %calibration piezo V --> um

info_flowers595_4K = load(strcat(datapath,'Info_0909_flowers_polarization.mat'));
time = str2num(extractBefore(info_flowers595_4K.exposuretime{3},'s'))*info_flowers595_4K.accumulations{3};
Peak_maxima = info_flowers595_4K.Maxima{3};
background_spectra = load(strcat(datapath,'background_2s_1accs_630nm_grat1.txt'));

info_flowers561_300K = load(strcat(datapath,'Info_2710_flowers_fits.mat'));
time_300K_561 = str2num(extractBefore(info_flowers561_300K.exposuretime{2},'s'))*info_flowers561_300K.accumulations{2};
Peak_maxima_300K_561 = info_flowers561_300K.Maxima{2};

info_flowers595_200K = load(strcat(datapath,'Info_0402_flowers_polarization.mat'));
time_200K_595 = str2num(extractBefore(info_flowers595_200K.exposuretime{2},'s'))*info_flowers595_200K.accumulations{2};
Peak_maxima_200K_595 = info_flowers595_200K.Maxima{2};
Angles = info_flowers595_200K.Angles{2};

%Calculate the x and y axes of the maps using the stepsize of the
%calibration
axisX = linspace(stepX4K*info_flowers595_4K.sample_x{3}(1)/10,stepX4K*info_flowers595_4K.sample_x{3}(end)/10,length(info_flowers595_4K.sample_x{3}));
axisY = linspace(stepY4K*info_flowers595_4K.sample_y{3}(1)/10,stepY4K*info_flowers595_4K.sample_y{3}(end)/10,length(info_flowers595_4K.sample_y{3}));

%%
%Shift the maps by a few pixels, so that they overlap exactly (because of
%the rotation of the halfwaveplate, the position shifts slightly over
%different excitation angles

alt_degrees_4K(1,:,:) = squeeze(Peak_maxima(1,1:end,2:end,1));
alt_degrees_4K(2,:,:) = squeeze(Peak_maxima(1,1:end,1:end-1,2));
alt_degrees_4K(3,:,:) = squeeze(Peak_maxima(1,1:end,1:end-1,3));
alt_degrees_4K(4,:,:) = squeeze(Peak_maxima(1,1:end,1:end-1,4));
alt_degrees_4K(5,:,:) = squeeze(Peak_maxima(1,1:end,1:end-1,5));

%%
%Plot Figure 2b: map of the flower marked in brown, upon vertical polarization excitation 

fg1 = figure(1); clf(fg1);  set(gcf,'Color','w');

imagesc(axisX(16:21),axisY(29:35),squeeze(alt_degrees_4K(1,29:35,16:21)))
hold on
teller = 1;
for ii = 30:34
    color_plot = [teller/5 1-teller/5 0];
    plot(axisX(19),axisY(ii),'o','color',color_plot,'MarkerFaceColor',color_plot)
    hold on
    teller = teller+1;
end

colorbar; caxis([0 9e3])
set(gca,'Xdir','reverse')
set(gca,'Ydir','normal')
title('Vertical excitation')
xlabel('x (\mum)')
ylabel('y (\mum)')

print(fg1,strcat(figurepath,'Figure2b.png'),'-dpng');

%%
%Plot Figure 2c: map of the flower marked in brown, upon diagonal polarization excitation 

fg2 = figure(2); clf(fg2);  set(gcf,'Color','w');

imagesc(axisX(16:21),axisY(29:35),squeeze(alt_degrees_4K(2,29:35,16:21)))
hold on
teller = 1;
for ii = 30:34
    color_plot = [teller/5 1-teller/5 0];
    plot(axisX(19),axisY(ii),'o','color',color_plot,'MarkerFaceColor',color_plot)
    hold on
    teller = teller+1;
end

colorbar; caxis([0 9e3])
set(gca,'Xdir','reverse')
set(gca,'Ydir','normal')
title('Diagonal excitation')
xlabel('x (\mum)')
ylabel('y (\mum)')

print(fg2,strcat(figurepath,'Figure2c.png'),'-dpng');

%%
%Plot Figure 2d: map of the flower marked in brown, upon horizontal polarization excitation 

fg3 = figure(3); clf(fg3);  set(gcf,'Color','w');

imagesc(axisX(16:21),axisY(29:35),squeeze(alt_degrees_4K(3,29:35,16:21)))
hold on
teller = 1;
for ii = 30:34
    color_plot = [teller/5 1-teller/5 0];
    plot(axisX(19),axisY(ii),'o','color',color_plot,'MarkerFaceColor',color_plot)
    hold on
    teller = teller+1;
end

colorbar; caxis([0 9e3])
set(gca,'Xdir','reverse')
set(gca,'Ydir','normal')
title('Horizontal excitation')
xlabel('x (\mum)')
ylabel('y (\mum)')

print(fg3,strcat(figurepath,'Figure2d.png'),'-dpng');

%%
%Plot Figure 2e: the Raman intensity as a function of the excitation
%polarization

fg4 = figure(4); clf(fg4); set(gcf,'Color','w');
teller = 1;
for ii = 30:34
    color_plot = [teller/5 1-teller/5 0];
    pl=plot(Angles,alt_degrees_4K(:,ii,19)/max(alt_degrees_4K(:,ii,19)),'o-','color',color_plot,'MarkerFaceColor',color_plot);
    hold on
    teller = teller+1;
end

xlabel('Linear polarization')
ylabel('Normalized intensity')
ylim([0.5 1])
xlim([0 90])
xticks([0 22.5 45 67.5 90 ])

print(fg4,strcat(figurepath,'Figure2e.png'),'-dpng');

%%
%Plot Figure 2g: map of the flower marked in purple, upon vertical polarization excitation 

fg5 = figure(5); clf(fg5);  set(gcf,'Color','w');

imagesc(axisX(13:19),axisY(1:11),squeeze(alt_degrees_4K(1,1:11,13:19)))
hold on
teller = 1;
for ii = 3:9
    color_plot = [teller/7 0 1-teller/7];
    plot(axisX(15),axisY(ii),'o','color',color_plot,'MarkerFaceColor',color_plot)
    hold on
    teller = teller+1;
end

colorbar; caxis([0 1.7e4])
set(gca,'Xdir','reverse')
set(gca,'Ydir','normal')
title('Vertical excitation')
xlabel('x (\mum)')
ylabel('y (\mum)')

print(fg5,strcat(figurepath,'Figure2g.png'),'-dpng');

%%
%Plot Figure 2h: map of the flower marked in purple, upon diagonal polarization excitation 

fg6 = figure(6); clf(fg6);  set(gcf,'Color','w');

imagesc(axisX(13:19),axisY(1:11),squeeze(alt_degrees_4K(2,1:11,13:19)))
hold on
teller = 1;
for ii = 3:9
    color_plot = [teller/7 0 1-teller/7];
    plot(axisX(15),axisY(ii),'o','color',color_plot,'MarkerFaceColor',color_plot)
    hold on
    teller = teller+1;
end

colorbar; caxis([0 1.7e4])
set(gca,'Xdir','reverse')
set(gca,'Ydir','normal')
title('Diagonal excitation')
xlabel('x (\mum)')
ylabel('y (\mum)')

print(fg6,strcat(figurepath,'Figure2h.png'),'-dpng');


%%
%Plot Figure 2i: map of the flower marked in purple, upon horizontal polarization excitation 

fg7 = figure(7); clf(fg7);  set(gcf,'Color','w');

imagesc(axisX(13:19),axisY(1:11),squeeze(alt_degrees_4K(3,1:11,13:19)))
hold on
teller = 1;
for ii = 3:9
    color_plot = [teller/7 0 1-teller/7];
    plot(axisX(15),axisY(ii),'o','color',color_plot,'MarkerFaceColor',color_plot)
    hold on
    teller = teller+1;
end

colorbar; caxis([0 1.7e4])
set(gca,'Xdir','reverse')
set(gca,'Ydir','normal')
title('Horizontal excitation')
xlabel('x (\mum)')
ylabel('y (\mum)')

print(fg7,strcat(figurepath,'Figure2i.png'),'-dpng');

%%
%Plot Figure 2j: the Raman intensity as a function of the excitation
%polarization

fg8 = figure(8); clf(fg8); set(gcf,'Color','w');
teller = 1;
for ii = 3:9
    color_plot = [teller/7 0 1-teller/7];
    pl=plot(Angles,alt_degrees_4K(:,ii,15)/max(alt_degrees_4K(:,ii,15)),'o-','color',color_plot,'MarkerFaceColor',color_plot);
    hold on
    teller = teller+1;
end

xlabel('Linear polarization')
ylabel('Normalized intensity')
ylim([0.65 1])
xlim([0 90])

xticks([0 22.5 45 67.5 90 ])

print(fg8,strcat(figurepath,'Figure2j.png'),'-dpng');

%%
%---------------------------------------------------------
%Plot Figure S4b: map of the flower marked in dark blue, upon vertical polarization excitation 

fg9 = figure(9); clf(fg9);  set(gcf,'Color','w');

imagesc(axisX(18:22),axisY(18:28),squeeze(alt_degrees_4K(1,18:28,18:22)))
hold on
teller = 1;
for ii = 23:27
    color_plot = [teller/5 1-teller/5 0];
    plot(axisX(20),axisY(ii),'o','color',color_plot,'MarkerFaceColor',color_plot)
    hold on
    teller = teller+1;
end

colorbar; caxis([0 1.3e4])
set(gca,'Xdir','reverse')
set(gca,'Ydir','normal')
title('Vertical excitation')
xlabel('x (\mum)')
ylabel('y (\mum)')

print(fg9,strcat(figurepath,'FigureS4b.png'),'-dpng');

%%
%Plot Figure S4c: map of the flower marked in dark blue, upon diagonal polarization excitation 

fg10 = figure(10); clf(fg10);  set(gcf,'Color','w');

imagesc(axisX(18:22),axisY(18:28),squeeze(alt_degrees_4K(2,18:28,18:22)))
hold on
teller = 1;
for ii = 23:27
    color_plot = [teller/5 1-teller/5 0];
    plot(axisX(20),axisY(ii),'o','color',color_plot,'MarkerFaceColor',color_plot)
    hold on
    teller = teller+1;
end

colorbar; caxis([0 1.3e4])
set(gca,'Xdir','reverse')
set(gca,'Ydir','normal')
title('Diagonal excitation')
xlabel('x (\mum)')
ylabel('y (\mum)')

print(fg10,strcat(figurepath,'FigureS4c.png'),'-dpng');


%%
%Plot Figure S4d: map of the flower marked in dark blue, upon horizontal polarization excitation 

fg11 = figure(11); clf(fg11);  set(gcf,'Color','w');

imagesc(axisX(18:22),axisY(18:28),squeeze(alt_degrees_4K(3,18:28,18:22)))
hold on
teller = 1;
for ii = 23:27
    color_plot = [teller/5 1-teller/5 0];
    plot(axisX(20),axisY(ii),'o','color',color_plot,'MarkerFaceColor',color_plot)
    hold on
    teller = teller+1;
end

colorbar; caxis([0 1.3e4])
set(gca,'Xdir','reverse')
set(gca,'Ydir','normal')
title('Horizontal excitation')
xlabel('x (\mum)')
ylabel('y (\mum)')

print(fg11,strcat(figurepath,'FigureS4d.png'),'-dpng');

%%
%Plot Figure S4e: the Raman intensity as a function of the excitation
%polarization

fg12 = figure(12); clf(fg12); set(gcf,'Color','w');
teller = 1;
for ii = 23:27
    color_plot = [teller/5 1-teller/5 0];
    pl=plot(Angles,alt_degrees_4K(:,ii,20)/max(alt_degrees_4K(:,ii,20)),'o-','color',color_plot,'MarkerFaceColor',color_plot);
    hold on
    teller = teller+1;
end

xlabel('Linear polarization')
ylabel('Normalized intensity')
ylim([0.5 1])
xlim([0 90])

xticks([0 22.5 45 67.5 90 ])

print(fg12,strcat(figurepath,'FigureS4e.png'),'-dpng');

%%
%Plot Figure S4g: map of the flower marked in red, upon vertical polarization excitation 

fg13 = figure(13); clf(fg13);  set(gcf,'Color','w');

imagesc(axisX(1:8),axisY(11:19),squeeze(alt_degrees_4K(1,11:19,1:8)))
hold on
teller = 1;
for ii = 12:17
    color_plot = [teller/6 0 1-teller/6];
    plot(axisX(4),axisY(ii),'o','color',color_plot,'MarkerFaceColor',color_plot)
    hold on
    teller = teller+1;
end

colorbar; caxis([0 1.6e4])
set(gca,'Xdir','reverse')
set(gca,'Ydir','normal')
title('Vertical excitation')
xlabel('x (\mum)')
ylabel('y (\mum)')

print(fg13,strcat(figurepath,'FigureS4g.png'),'-dpng');

%%
%Plot Figure S4h: map of the flower marked in red, upon diagonal polarization excitation 

fg14 = figure(14); clf(fg14);  set(gcf,'Color','w');

imagesc(axisX(1:8),axisY(11:19),squeeze(alt_degrees_4K(2,11:19,1:8)))
hold on
teller = 1;
for ii = 12:17
    color_plot = [teller/6 0 1-teller/6];
    plot(axisX(4),axisY(ii),'o','color',color_plot,'MarkerFaceColor',color_plot)
    hold on
    teller = teller+1;
end

colorbar; caxis([0 1.6e4])
set(gca,'Xdir','reverse')
set(gca,'Ydir','normal')
title('Diagonal excitation')
xlabel('x (\mum)')
ylabel('y (\mum)')

print(fg14,strcat(figurepath,'FigureS4h.png'),'-dpng');


%%
%Plot Figure S4i: map of the flower marked in red, upon horizontal polarization excitation 

fg15 = figure(15); clf(fg15);  set(gcf,'Color','w');

imagesc(axisX(1:8),axisY(11:19),squeeze(alt_degrees_4K(3,11:19,1:8)))
hold on
teller = 1;
for ii = 12:17
    color_plot = [teller/6 0 1-teller/6];
    plot(axisX(4),axisY(ii),'o','color',color_plot,'MarkerFaceColor',color_plot)
    hold on
    teller = teller+1;
end

colorbar; caxis([0 1.6e4])
set(gca,'Xdir','reverse')
set(gca,'Ydir','normal')
title('Horizontal excitation')
xlabel('x (\mum)')
ylabel('y (\mum)')

print(fg15,strcat(figurepath,'FigureS4i.png'),'-dpng');

%%
%Plot Figure S4j: the Raman intensity as a function of the excitation
%polarization

fg16 = figure(16); clf(fg16); set(gcf,'Color','w');
teller = 1;
for ii = 12:17
    color_plot = [teller/6 0 1-teller/6];
    pl=plot(Angles,alt_degrees_4K(:,ii,4)/max(alt_degrees_4K(:,ii,4)),'o-','color',color_plot,'MarkerFaceColor',color_plot);
    hold on
    teller = teller+1;
end

xlabel('Linear polarization')
ylabel('Normalized intensity')
ylim([0.5 1])
xlim([0 90])

xticks([0 22.5 45 67.5 90 ])

print(fg16,strcat(figurepath,'FigureS4j.png'),'-dpng');

%%
alt_degrees_4K_Amode(1,:,:) = squeeze(Peak_maxima(2,1:end,2:end,1));
alt_spectra_4K(:,:,:,1) = squeeze(info_flowers595_4K.Spectrum{3}(:,1:end,2:end,1)-background_spectra(:,3));

alt_degrees_4K_Amode(2,:,:) = squeeze(Peak_maxima(2,1:end,1:end-1,2));
alt_spectra_4K(:,:,:,2) = squeeze(info_flowers595_4K.Spectrum{3}(:,1:end,1:end-1,2)-background_spectra(:,3));

alt_degrees_4K_Amode(3,:,:) = squeeze(Peak_maxima(2,1:end,1:end-1,3));
alt_spectra_4K(:,:,:,3) = squeeze(info_flowers595_4K.Spectrum{3}(:,1:end,1:end-1,3)-background_spectra(:,3));

alt_degrees_4K_Amode(4,:,:) = squeeze(Peak_maxima(2,1:end,1:end-1,4));
alt_spectra_4K(:,:,:,4) = squeeze(info_flowers595_4K.Spectrum{3}(:,1:end,1:end-1,4)-background_spectra(:,3));

alt_degrees_4K_Amode(5,:,:) = squeeze(Peak_maxima(2,1:end,1:end-1,5));
alt_spectra_4K(:,:,:,5) = squeeze(info_flowers595_4K.Spectrum{3}(:,1:end,1:end-1,5)-background_spectra(:,3));


%%
%Plot Figure S5a: Raman spectra as a function of excitation polarization

fg17 = figure(17); clf(fg17); set(gcf,'Color','w');

for ii = 1:5
    color_plot = [ii/5 1-ii/5 0]
    if ii == 3;
        color_plot = 'y'
    end
    pl = plot(info_flowers595_4K.Raman{3},alt_spectra_4K(:,34,19,ii),'color',color_plot)
    hold on
end

xlim([200 1000])
ylim([-1e2 7e3])
legend('0','22.5','45','67.5','90')
xlabel('\Delta \nu (cm^{-1})')
ylabel('I (counts/s)')

print(fg17,strcat(figurepath,'FigureS5a.png'),'-dpng');


%%
%Plot Figure S5b: the Raman intensity of the A1g mode as a function of the excitation
%polarization

fg18 = figure(18); clf(fg18); set(gcf,'Color','w');
teller = 1;
for ii = 30:34
    color_plot = [teller/5 1-teller/5 0];
    pl=plot(Angles,alt_degrees_4K_Amode(:,ii,19)/max(alt_degrees_4K_Amode(:,ii,19)),'o-','color',color_plot,'MarkerFaceColor',color_plot);
    hold on
    teller = teller+1;
end

xlabel('Linear polarization')
ylabel('Normalized intensity')
ylim([0.5 1])
xlim([0 90])
xticks([0 22.5 45 67.5 90 ])

print(fg18,strcat(figurepath,'FigureS5b.png'),'-dpng');


%%
%Plot Figure S5c: Raman spectra as a function of excitation polarization

fg19 = figure(19); clf(fg19); set(gcf,'Color','w');

for ii = 1:5
    color_plot = [ii/5 0 1-ii/5]
    if ii == 3;
        color_plot = 'm'
    end
    plot(info_flowers595_4K.Raman{3},alt_spectra_4K(:,4,15,ii)/time,'color',color_plot);
    hold on
end

xlim([200 1000])
ylim([-1e2 1e4])
legend('0','22.5','45','67.5','90')
xlabel('\Delta \nu (cm^{-1})')
ylabel('I (counts/s)')

print(fg19,strcat(figurepath,'FigureS5b.png'),'-dpng');

%%
%Plot Figure S5d: the Raman intensity as a function of the excitation
%polarization

fg20 = figure(20); clf(fg20); set(gcf,'Color','w');
teller = 1;
for ii = 3:9
    color_plot = [teller/7 0 1-teller/7];
    pl=plot(Angles,alt_degrees_4K_Amode(:,ii,15)/max(alt_degrees_4K_Amode(:,ii,15)),'o-','color',color_plot,'MarkerFaceColor',color_plot);
    hold on
    teller = teller+1;
end

xlabel('Linear polarization')
ylabel('Normalized intensity')
ylim([0.65 1])
xlim([0 90])

xticks([0 22.5 45 67.5 90 ])

print(fg20,strcat(figurepath,'FigureS5d.png'),'-dpng');

%%
%------------------------------------------------------------------
%Now we go to the dataset at 200K, with a 595nm excitation
%------------------------------------------------------------------
%Shift the maps by a few pixels, so that they overlap exactly (because of
%the rotation of the halfwaveplate, the position shifts slightly over
%different excitation angles

alt_degrees_200K_595 = [];
alt_degrees_200K_595(1,:,:) = squeeze(Peak_maxima_200K_595(1,1:end,4:end,1));
alt_degrees_200K_595(2,:,:) = squeeze(Peak_maxima_200K_595(1,1:end,1:end-3,2));
alt_degrees_200K_595(3,:,:) = squeeze(Peak_maxima_200K_595(1,1:end,1:end-3,3));
alt_degrees_200K_595(4,:,:) = squeeze(Peak_maxima_200K_595(1,1:end,1:end-3,4));
alt_degrees_200K_595(5,:,:) = squeeze(Peak_maxima_200K_595(1,1:end,1:end-3,5));

%%
%Plot Figure S5e: the Raman intensity as a function of the excitation
%polarization, at 200K

fg21 = figure(21); clf(fg21); set(gcf,'Color','w');
teller = 1;
for ii = 18:20
    color_plot = [teller/6 1-teller/6 0];
    pl=plot(Angles,alt_degrees_200K_595(:,ii,18)/max(alt_degrees_200K_595(:,ii,18)),'o-','color',color_plot,'MarkerFaceColor',color_plot);
    hold on
    teller = teller+1;
end
for ii = 18:20
    color_plot = [teller/6 1-teller/6 0];
    pl=plot(Angles,alt_degrees_200K_595(:,ii,19)/max(alt_degrees_200K_595(:,ii,19)),'o-','color',color_plot,'MarkerFaceColor',color_plot);
    hold on
    teller = teller+1;
end

xlabel('Linear polarization')
ylabel('Normalized intensity')
title('595nm excitation, 200K')
ylim([0.5 1])
xlim([0 90])
xticks([0 22.5 45 67.5 90 ])

print(fg21,strcat(figurepath,'FigureS5e.png'),'-dpng');

%%
%Plot Figure S5f: the Raman intensity as a function of the excitation
%polarization, at 200K

fg22 = figure(22); clf(fg22); set(gcf,'Color','w');
teller = 1;
for ii = 3:4
    color_plot = [teller/6 0 1-teller/6];
    pl=plot(Angles,alt_degrees_200K_595(:,ii,15)/max(alt_degrees_200K_595(:,ii,15)),'o-','color',color_plot,'MarkerFaceColor',color_plot);
    hold on
    teller = teller+1;
end
for ii = 1:2
    color_plot = [teller/6 0 1-teller/6];
    pl=plot(Angles,alt_degrees_200K_595(:,ii,16)/max(alt_degrees_200K_595(:,ii,16)),'o-','color',color_plot,'MarkerFaceColor',color_plot);
    hold on
    teller = teller+1;
end
for ii = 2:3
    color_plot = [teller/6 0 1-teller/6];
    pl=plot(Angles,alt_degrees_200K_595(:,ii,17)/max(alt_degrees_200K_595(:,ii,17)),'o-','color',color_plot,'MarkerFaceColor',color_plot);
    hold on
    teller = teller+1;
end

xlabel('Linear polarization')
ylabel('Normalized intensity')
title('595nm excitation, 200K')
ylim([0.5 1])
xlim([0 90])
xticks([0 22.5 45 67.5 90 ])

print(fg22,strcat(figurepath,'FigureS5f.png'),'-dpng');

%%
%------------------------------------------------------------------
%Now we go to the dataset at 300K, with a 561nm excitation
%------------------------------------------------------------------
%Shift the maps by a few pixels, so that they overlap exactly (because of
%the rotation of the halfwaveplate, the position shifts slightly over
%different excitation angles

alt_degrees_300K_561=[];
alt_degrees_300K_561(1,:,:) = squeeze(Peak_maxima_300K_561(1,1:end-1,2:end,1));
alt_degrees_300K_561(2,:,:) = squeeze(Peak_maxima_300K_561(1,2:end,2:end,2));
alt_degrees_300K_561(3,:,:) = squeeze(Peak_maxima_300K_561(1,2:end,1:end-1,3));
alt_degrees_300K_561(4,:,:) = squeeze(Peak_maxima_300K_561(1,2:end,1:end-1,4));
alt_degrees_300K_561(5,:,:) = squeeze(Peak_maxima_300K_561(1,2:end,1:end-1,5));

%%
%Plot Figure S5g: the Raman intensity as a function of the excitation
%polarization, with a 561nm excitation

fg23 = figure(23); clf(fg23); set(gcf,'Color','w');
teller = 1;
for ii = 24:26
    kleur = [teller/3 1-teller/3 0];
    pl=plot(Angles,alt_degrees_300K_561(:,ii,20)/max(alt_degrees_300K_561(:,ii,20)),'o-','color',kleur,'MarkerFaceColor',kleur);
    hold on
    teller = teller+1;
end

xlabel('Linear polarization')
ylabel('Normalized intensity')
title('561nm excitation, 300K')
ylim([0.3 1])
xlim([0 90])
xticks([0 22.5 45 67.5 90 ])

print(fg23,strcat(figurepath,'FigureS5g.png'),'-dpng');

%%
%Plot Figure S5h: the Raman intensity as a function of the excitation
%polarization, with a 561nm excitation

fg24 = figure(24); clf(fg24); set(gcf,'Color','w');
teller = 1;
for ii = 5:8
    kleur = [teller/5 0 1-teller/5];
    pl=plot(Angles,alt_degrees_300K_561(:,ii,16)/max(alt_degrees_300K_561(:,ii,16)),'o-','color',kleur,'MarkerFaceColor',kleur);
    hold on
    teller = teller+1;
end

xlabel('Linear polarization')
ylabel('Normalized intensity')
title('561nm excitation, 300K')
ylim([0.5 1])
xlim([0 90])
xticks([0 22.5 45 67.5 90 ])

print(fg24,strcat(figurepath,'FigureS5h.png'),'-dpng');



