%--------------------------------------------------------------------------
%--------------------------------------------------------------------------
%This is the software to make the images for article

%Requirements:
%   -change path into the path to your folder
%   -make sure the data are in the data folder
%   -make sure there is an image folder to save the images to
%--------------------------------------------------------------------------
%--------------------------------------------------------------------------

clc;
clear;
close all;

path = 'N:\tnw\NS\kuiperslab\Irina\writing_articles\article_flowers\open_data\';

datapath = strcat(path,'data\');
figurepath=strcat(path,'images\');

%%
%This software does the following:
%   import information of fitted Raman spectra at different temperatures
%   plot spectra
%   plot a map of the Raman intensity
%   plot subfigures 1c,d and subfigures 4a,b
%   plot figures S1, S2, S3 of the supplementary materials

%%
%Import all the fitted spectra and the results of the fit

stepX300K = 11.0; stepY300K = 7.0; %calibration piezo V --> um
stepX200K = 9.0; stepY200K = 5.0; %calibration piezo V --> um
stepX100K = 6.0; stepY100K = 3.8;%calibration piezo V --> um
stepX4K = 3.5; stepY4K = 2.3;  %calibration piezo V --> um

info_flowers595_4K = load(strcat(datapath,'Info_0809_flowers_fits.mat'));
time(1) = str2num(extractBefore(info_flowers595_4K.exposuretime{1},'s'))*info_flowers595_4K.accumulations{1};
place(1) = 1;

info_flowers561_4K = load(strcat(datapath,'Info_1109_flowers_fits.mat'));
time(2) = str2num(extractBefore(info_flowers561_4K.exposuretime{2},'s'))*info_flowers561_4K.accumulations{2};
place(2) = 2;

info_flowers561_100K = load(strcat(datapath,'Info_1709_flowers_fits.mat'));
time(3) = str2num(extractBefore(info_flowers561_100K.exposuretime{1},'s'))*info_flowers561_100K.accumulations{1};
place(3) = 1;

info_flowers561_200K = load(strcat(datapath,'Info_2309_flowers_fits.mat'));
time(4) = str2num(extractBefore(info_flowers561_200K.exposuretime{2},'s'))*info_flowers561_200K.accumulations{2};
place(4) = 2;

info_flowers561_300K = load(strcat(datapath,'Info_2710_flowers_fits.mat'));
time(5) = str2num(extractBefore(info_flowers561_300K.exposuretime{1},'s'))*info_flowers561_300K.accumulations{1};
place(5) = 1;

%%
info_some_flowers = load(strcat(datapath,'Info_some_flowers.mat'));

info_flakes = load(strcat(datapath,'Info_flakes.mat'));

spectrum_threelayer = load(strcat(datapath,'spectrum_threelayer.txt'));
spectrum_fivelayer = load(strcat(datapath,'spectrum_fivelayer.txt'));
background_fewlayers = load(strcat(datapath,'background_10s_grating2_700nm.txt'));


%%
%Figure 1c: plot a map of the Raman peak intensity

posX(1) = 11;  posY(1) = 18;    kleur{1} = 'r';
posX(2) = 25;  posY(2) = 30;    kleur{2} = 'm';
posX(3) = 14;  posY(3) = 27;    kleur{3} = 'g';

axisX = linspace(stepX4K*info_flowers595_4K.sample_x{1}(1)/10,stepX4K*info_flowers595_4K.sample_x{1}(32)/10,length(info_flowers595_4K.sample_x{1}));
axisY = linspace(stepY4K*info_flowers595_4K.sample_y{1}(1)/10,stepY4K*info_flowers595_4K.sample_y{1}(end)/10,length(info_flowers595_4K.sample_y{1}));

fg1 = figure(1); clf(fg1);  set(gcf,'Color','w');

imagesc(axisX,axisY,squeeze(info_flowers595_4K.Maxima_Lorentz_595{1}(1,:,1:32))/time(1)*2)  %wrong definition of Lorentzian in fit...
hold on
for ii = 1:3
    pl{ii}=plot(axisX(posX(ii)),axisY(posY(ii)),'p','color',kleur{ii},'MarkerFaceColor',kleur{ii},'markersize',15);
    hold on
end

colormap parula; colorbar;
set(gca,'Xdir','reverse')
set(gca,'Ydir','normal')
xlabel('x (\mum)')
ylabel('y (\mum)')

print(fg1,strcat(figurepath,'Figure1c.png'),'-dpng');

%%
%Figure 1d: plot the three spectra at different positions

fg2 = figure(2); clf(fg2);  set(gcf,'Color','w');

plot(info_flowers595_4K.Raman{1},(info_flowers595_4K.Spectrum{1}(:,posY(1),posX(1))-info_flowers595_4K.background{1}(:,3))/time(1),'r');
hold on
plot(info_flowers595_4K.Raman{1},(info_flowers595_4K.Spectrum{1}(:,posY(2),posX(2))-info_flowers595_4K.background{1}(:,3))/time(1),'m');
hold on
plot(info_flowers595_4K.Raman{1},(info_flowers595_4K.Spectrum{1}(:,posY(3),posX(3))-info_flowers595_4K.background{1}(:,3))/time(1),'g');
hold off

xlim([200 1500])
xlabel('\Delta \nu (cm^{-1})')
ylabel('I (counts/s)')

print(fg2,strcat(figurepath,'Figure 1d.png'),'-dpng');

%%
%Figure 4a: plot the three spectra at different temperatures

fg3 = figure(3); clf(fg3);  set(gcf,'Color','w');

plot(info_flowers595_4K.Raman{1},(info_flowers595_4K.Spectrum{1}(:,18,11)-info_flowers595_4K.background{1}(:,3))/time(1),'r');
hold on
plot(info_some_flowers.Raman{1},(info_some_flowers.Spectrum{1}-info_some_flowers.background{1}(:,3))/info_some_flowers.time(1),'color',[0.5 0 0.5]);
hold on
plot(info_some_flowers.Raman{2},(info_some_flowers.Spectrum{2}-info_some_flowers.background{2}(:,3))/info_some_flowers.time(2),'b');
hold off

xlabel('\Delta \nu (cm^{-1})')
ylabel('I (counts/s)')
legend('4K','150K','300K')
xlim([200 1500])

print(fg3,strcat(figurepath,'Figure4a.png'),'-dpng');

%%
%Figure 4b: plot the two spectra at different temperatures

fg4 = figure(4); clf(fg4);  set(gcf,'Color','w');

plot(info_flowers561_4K.Raman{2},(info_flowers561_4K.Spectrum{2}(:,19,3)-info_flowers561_4K.background{2}(:,3))/time(2),'r');
hold on
plot(info_flowers561_300K.Raman,(info_flowers561_300K.Spectrum(:,25,11)-info_flowers561_300K.background(:,3))/time(5),'b');
hold off

xlabel('\Delta \nu (cm^{-1})')
ylabel('I (counts/s)')
legend('4K','300K')
xlim([200 1500])

print(fg4,strcat(figurepath,'Figure4b.png'),'-dpng');

%%
%Plot Figure S1d from the supplementary materials

fg5 = figure(5); clf(fg5);  set(gcf,'Color','w');

pl1=plot(info_flowers595_4K.wavelength{1},(info_flowers595_4K.Spectrum{1}(:,5,29)-info_flowers595_4K.background{1}(:,3))/time(1),'color',[1 0.5 0]);
hold on
pl2=plot(info_flowers561_4K.wavelength{2},(info_flowers561_4K.Spectrum{2}(:,6,23)-info_flowers561_4K.background{2}(:,3))/time(2)*4,'g');
hold on
pl3=plot(info_flakes.wavelength_flakes{1},info_flakes.Spectrum_flakes{1}*10*0.02,'r');
hold on
pl4=plot(info_flakes.wavelength_flakes{2},info_flakes.Spectrum_flakes{2}*0.1,'color',[0 0.5 0]);
hold off

xlim([570 660])
ylim([-1e2 1.8e4])
xlabel('wavelength (nm)')
ylabel('I (counts/s)')
legend('flower 595nm','flower 561nm x4','monolayer 595nm x0.02','monolayer 561nm x0.1')
title('4K - flowers vs monolayer')

print(fg5,strcat(figurepath,'FigureS1d.png'),'-dpng');

%%
%Plot Figure S1c from the supplementary materials

fg6 = figure(6); clf(fg6);  set(gcf,'Color','w');

pl1=plot(info_some_flowers.wavelength{3},(info_some_flowers.Spectrum{3}-info_some_flowers.background{3}(:,3))/info_some_flowers.time(3),'color',[1 0.5 0]);
hold on
pl2=plot(info_flowers561_100K.wavelength,(info_flowers561_100K.Spectrum(:,15,10)-info_flowers561_100K.background(:,3))/time(3)*3,'g');
hold on
pl3=plot(info_flakes.wavelength_flakes{3},info_flakes.Spectrum_flakes{3}*10*0.02,'r');
hold on
pl4=plot(info_flakes.wavelength_flakes{4},info_flakes.Spectrum_flakes{4}*0.06,'color',[0 0.5 0]);
hold off

xlim([570 660])
xlabel('wavelength (nm)')
ylabel('I (counts/s)')
legend('flower 595nm','flower 561nm x3','monolayer 595nm x0.02','monolayer 561nm x0.06')
title('100K - flowers vs monolayer')

print(fg6,strcat(figurepath,'FigureS1c.png'),'-dpng');

%%
%Plot Figure S1b from the supplementary materials

fg6 = figure(6); clf(fg6);  set(gcf,'Color','w');

pl1=plot(info_some_flowers.wavelength{4},(info_some_flowers.Spectrum{4}-info_some_flowers.background{4}(:,3))/info_some_flowers.time(4),'color',[1 0.5 0]);
hold on
pl2=plot(info_flowers561_200K.wavelength{2},(info_flowers561_200K.Spectrum{2}(:,4,15)-info_flowers561_200K.background{2}(:,3))/time(4)*3,'g');
hold on
pl3=plot(info_flakes.wavelength_flakes{5},info_flakes.Spectrum_flakes{5}*0.02,'r');
hold on
pl4=plot(info_flakes.wavelength_flakes{6},info_flakes.Spectrum_flakes{6}*0.06,'color',[0 0.5 0]);
hold off

xlim([570 660])
xlabel('wavelength (nm)')
ylabel('I (counts/s)')
legend('flower 595nm','flower 561nm x3','monolayer 595nm x0.02','monolayer 561nm x0.06')
title('200K - flowers vs monolayer')

print(fg6,strcat(figurepath,'FigureS1b.png'),'-dpng');

%%
%Plot Figure S1a from the supplementary materials

fg7 = figure(7); clf(fg7);  set(gcf,'Color','w');

plot(info_some_flowers.wavelength{5},(info_some_flowers.Spectrum{5}-info_some_flowers.background{5}(:,3))/info_some_flowers.time(5),'color',[1 0.5 0]);
hold on
plot(info_flowers561_300K.wavelength,(info_flowers561_300K.Spectrum(:,16,5)-info_flowers561_300K.background(:,3))/time(5)*3,'g');
hold on
plot(info_flakes.wavelength_flakes{7},info_flakes.Spectrum_flakes{7}*0.02,'r');
hold on
plot(info_flakes.wavelength_flakes{8},info_flakes.Spectrum_flakes{8}*0.1,'color',[0 0.5 0]);
hold off

xlim([570 660])
xlabel('wavelength (nm)')
ylabel('I (counts/s)')
legend('flower 595nm','flower 561nm x3','monolayer 595nm x0.02','monolayer 561nm x0.1')
title('300K - flowers vs monolayer')

print(fg7,strcat(figurepath,'FigureS1a.png'),'-dpng');

%%
range2 = 300:1024;

fg8 = figure(8); clf(fg8); set(gcf,'Color','w');

plot(info_some_flowers.wavelength{5},(info_some_flowers.Spectrum{5}-info_some_flowers.background{5}(:,3))/info_some_flowers.time(5),'color',[1 0.5 0]);
hold on
plot(spectrum_threelayer(:,2),(spectrum_threelayer(:,3)-background_fewlayers(:,3))/10,'b--');
hold on
plot(spectrum_fivelayer(:,2),(spectrum_fivelayer(:,3)-background_fewlayers(:,3))/10,'--','color',[0 0.5 0.5]);
hold off

xlabel('wavelength (nm)');
ylabel('I (counts/s)');
legend('flower','trilayer','5 layers')

xlim([600 820])
ylim([-1e2 3.5e3])

print(fg8,strcat(figurepath,'Figure S1e.png'),'-dpng');

%%
%Plot Figure S2a

fg9 = figure(9); clf(fg9); set(gcf,'Color','w');

plot(info_some_flowers.Raman{2},(info_some_flowers.Spectrum{2}-info_some_flowers.background{2}(:,3))/5,'color',[1 0.5 0]);
hold on
plot(info_flowers561_300K.Raman,(info_flowers561_300K.Spectrum(:,25,12)-info_flowers561_300K.background(:,3))/time(5)*4,'g');
hold off

legend('595nm','561nm*4')
xlabel('\Delta \nu [cm^{-1}]');
ylabel('I (counts/s)');
xlim([200 1500])

print(fg9,strcat(figurepath,'FigureS2a.png'),'-dpng');

%%
%Plot Figure S2b from the supplementary materials

fg10 = figure(10); clf(fg10); set(gcf,'Color','w');

plot(info_some_flowers.Raman{2},(info_some_flowers.Spectrum{2}-info_some_flowers.background{2}(:,3))/5,'r');
hold on
pl3=plot(490,2.5e3,'d','color','k','MarkerFaceColor','k','MarkerSize',10);
hold on
pl4=plot(840,2.5e3,'*k','MarkerSize',15,'LineWidth',2);
hold off

xlabel('\Delta \nu [cm^{-1}]');
ylabel('I (counts/s)');
xlim([200 1500])
ylim([-1e3 9e3])

print(fg10,strcat(figurepath,'FigureS2b.png'),'-dpng');

%%
%Plot Figure S3b from the supplementary materials

fg11 = figure(11); clf(fg11); set(gcf,'Color','w');

plot(info_some_flowers.Raman{8},(info_some_flowers.Spectrum{8}-info_some_flowers.background{8}(:,3))/info_some_flowers.time(8),'g');

xlabel('\Delta \nu [cm^{-1}]');
ylabel('I (counts/s)');
xlim([200 1700])
ylim([0 6e2])

print(fg11,strcat(figurepath,'FigureS3b.png'),'-dpng');

%%
%Plot Figure S3b from the supplementary materials

fg12 = figure(12); clf(fg12); set(gcf,'Color','w');

plot(info_some_flowers.Raman{7},(info_some_flowers.Spectrum{7}-info_some_flowers.background{7}(:,3))/info_some_flowers.time(7),'m');

xlabel('\Delta \nu [cm^{-1}]');
ylabel('I (counts/s)');
xlim([200 1700])
ylim([0 9e2])

print(fg12,strcat(figurepath,'FigureS3c.png'),'-dpng');

%%
%Plot Figure S3d from the supplementary materials

fg13 = figure(13); clf(fg13); set(gcf,'Color','w');

plot(info_some_flowers.Raman{6},(info_some_flowers.Spectrum{6}-info_some_flowers.background{6}(:,3))/info_some_flowers.time(6),'b');

xlabel('\Delta \nu [cm^{-1}]');
ylabel('I (counts/s)');
xlim([200 1700])
ylim([0 1.0e3])

print(fg13,strcat(figurepath,'FigureS3d.png'),'-dpng');




